@@ -67,16 +67,16 @@ class Application(object):
         return self.__resource and self.__resource.name or self.__menu_entry.get_name()
     
     def get_description(self):
-        return self.__resource and self.__resource.description or ""
+        return getattr(self.__resource, "description", "")
 
     def get_tooltip(self):
-        return self.__resource and self.__resource.tooltip or ""
+        return getattr(self.__resource, "tooltip", "")
     
     def get_generic_name(self):
-        return self.__resource and self.__resource.genericName or ""
+        return getattr(self.__resource, "genericName", "")
 
     def get_usage_count(self):
-        return self.__resource and int(self.__resource.usageCount) or 0
+        return getattr(self.__resource, "usageCount", 0)
 
     def get_category(self):
         ## FIXME should this be category or categoryDisplayName ?       
@@ -183,12 +183,17 @@ class AppsHttpDownloader:
         #id = node.getAttribute("id")
         #_logger.debug("parsing application id=%s", id)
         attrs = xml_get_attrs(node, ['id', 'rank', 'usageCount', 
-                                     'iconUrl', 
+                                     'iconUrl',
                                      'category',
                                      'name', 'desktopNames', 'packageNames',
                                      ('tooltip', True),
                                      ('genericName', True)
                                     ])
+        # If we leave rank and usageCount as strings, then in the
+        # future, cmp() will return bogus results
+        attrs['rank'] = int(attrs['rank'])
+        attrs['usageCount'] = int(attrs['usageCount'])
+        attrs['iconUrl'] = urlparse.urljoin(globals.get_baseurl(), attrs['iconUrl'])
         description = xml_query(node, 'description#')
         if description:
             attrs['description'] = description
@@ -227,7 +232,7 @@ class AppsHttpDownloader:
                                     child_nodes=reply_root.childNodes)
         self.__handler(apps)
 
-    def __on_error(self, url, args):
+    def __on_error(self, url, response):
         if response and 'status' in response and response['status'] == '504':
             _logger.debug("don't have local cache for %s", url)
         else:
@@ -654,6 +659,13 @@ class AppSearchResult(search.SearchResult):
 
     def get_icon(self):
         """Returns an icon for the result"""
+        if self.__app.get_icon_url():
+            # Return None so that the the icon URL is used; this matches
+            # what we show in the browser
+            return None
+        else:
+            return self.__app.get_local_pixbuf()
+        
         return None
     
     def get_icon_url(self):
