@@ -13,7 +13,7 @@ from bigboard.libbig.logutil import log_except
 from bigboard.libbig.gutil import *
 from bigboard.workboard import WorkBoard
 from bigboard.stock import Stock
-from bigboard.slideout import ThemedSlideout
+from bigboard.slideout import Slideout
 import bigboard.google as google
 import bigboard.google_stock as google_stock  
 from bigboard.big_widgets import IconLink, CanvasHBox, CanvasVBox, Button, Header
@@ -189,7 +189,6 @@ class LocalFile(File):
 
     def get_type(self):
         if self._mimetype:
-            _logger.debug("mimetype is %s class is %s dir %s" % (self._mimetype, self._mimetype.__class__, dir(self._mimetype)))  
             return gnomevfs.mime_get_description(self._mimetype)
         return None
 
@@ -308,15 +307,15 @@ def get_menu_pixbuf(menuentry, size=48):
         return None
     return pixbuf
     
-class FileSlideout(ThemedSlideout):
-    def __init__(self, fobj):
-        super(FileSlideout, self).__init__()
-        vbox = CanvasVBox(border_color=0x0000000ff, spacing=4)
+class FileSlideout(Slideout):
+    def __init__(self, fobj, stylesheet=None):
+        super(FileSlideout, self).__init__(stylesheet=stylesheet)
+        self.__header = hippo.CanvasBox(classes='slideout-header')
+        self.get_root().append(self.__header)
+        vbox = CanvasVBox(border_color=0x0000000ff, spacing=4, classes='slideout-main')
         self.get_root().append(vbox)
-        self.__header = Header(topborder=False)
         text = hippo.CanvasText(classes='header', text=fobj.get_name(), xalign=hippo.ALIGNMENT_START)
         self.__header.append(text, hippo.PACK_EXPAND)        
-        vbox.append(self.__header)
         
         hbox = CanvasHBox(spacing=4, padding=4)
         img = hippo.CanvasImage(scale_width=60, scale_height=60, xalign=hippo.ALIGNMENT_START, yalign=hippo.ALIGNMENT_START)
@@ -327,12 +326,12 @@ class FileSlideout(ThemedSlideout):
         detailvbox = CanvasVBox(spacing=3)
         hbox.append(detailvbox) 
         if fobj.get_type():
-            text = hippo.CanvasText(classes='subforeground', text=fobj.get_type(), font='12px', xalign=hippo.ALIGNMENT_START)                  
+            text = hippo.CanvasText(classes='subforeground', text=fobj.get_type(), id='file-desc', xalign=hippo.ALIGNMENT_START)                  
             detailvbox.append(text)
         size = fobj.get_size()            
         if size is not None:
             sizestr = format_file_size(size)
-            text = hippo.CanvasText(classes='subforeground', text=sizestr, font='12px', xalign=hippo.ALIGNMENT_START)             
+            text = hippo.CanvasText(classes='subforeground', text=sizestr, id='file-desc', xalign=hippo.ALIGNMENT_START)             
             detailvbox.append(text)
         fname = os.path.dirname(fobj.get_full_name())
         if fname is not None and len(fname) > 0: 
@@ -342,7 +341,7 @@ class FileSlideout(ThemedSlideout):
             if fname.startswith(home):
                 fname = fname[:len(home)]
             fname = urllib.unquote(fname)            
-            text = hippo.CanvasText(classes='subforeground', text=fname, font='12px', xalign=hippo.ALIGNMENT_START)          
+            text = hippo.CanvasText(classes='subforeground', text=fname, id='file-desc', xalign=hippo.ALIGNMENT_START)          
             detailvbox.append(text)
         if isinstance(fobj, GoogleFile) :
             def activate_file(button):
@@ -357,7 +356,7 @@ class FileSlideout(ThemedSlideout):
             return    
         apps = gnomevfs.mime_get_all_applications(mime)
         if apps:
-            text = hippo.CanvasText(text='Open With: ', font='14px')
+            text = hippo.CanvasText(text='Open With: ')
             detailvbox.append(text)
             def on_app_clicked(button, app):
                 self.emit('close', True)
@@ -365,7 +364,6 @@ class FileSlideout(ThemedSlideout):
                 _launch_vfsmimeapp(app, fobj.get_url())      
             directory = apps_directory.get_app_directory()
             for app in apps:
-                _logger.debug("mime type: %s got app %s", mime, app)
                 button = hippo.CanvasButton()
                 labelhbox = gtk.HBox()
                 labelhbox.set_border_width(1)
@@ -412,8 +410,6 @@ class FilesStock(Stock, google_stock.GoogleStock):
         self.__slideout_target = None
         self.__last_slideout_event_time = None   
 
-        self.desktop_path = self._panel.get_desktop_path()
-
         self._box = hippo.CanvasBox(orientation=hippo.ORIENTATION_VERTICAL, spacing=4, padding_top=2)
         self._recentbox = hippo.CanvasBox(orientation=hippo.ORIENTATION_VERTICAL, spacing=4)
         self._box.append(self._recentbox)
@@ -454,24 +450,29 @@ class FilesStock(Stock, google_stock.GoogleStock):
 
     def remove_google_data(self, gobj):
         self.__remove_files_for_key(gobj)
+
+    def __close_slideout(self):
+        self.__slideout.destroy()
+        self.__slideout = None
+        self.__slideout_target = None
+        self._set_active(False)
         
     def on_file_activated(self, fobj, lnk, from_bigboard=True):
         _logger.debug("got file activated: %s", fobj)
         if self.__slideout is not None:
-            self.__slideout.destroy()
-            self.__slideout = None      
+            self.__close_slideout()
         if fobj == self.__slideout_target and \
            self.__last_slideout_event_time == gtk.get_current_event_time():
             self.__slideout_target = None            
             return
-        self.__slideout_target = fobj            
-        self.__slideout = FileSlideout(fobj)
+        self._set_active(True)
+        self.__slideout_target = fobj
+        self.__slideout = FileSlideout(fobj, stylesheet=self.get_path('slideout.css'))
         def on_slideout_close(s, action_taken):
             self.__last_slideout_event_time = gtk.get_current_event_time()
             if action_taken:
                 self._panel.action_taken()
-            s.destroy()
-            self.__slideout = None
+            self.__close_slideout()
         self.__slideout.connect('close', on_slideout_close)
         item = lnk.link
         coords = item.get_context().translate_to_screen(item)
@@ -481,15 +482,13 @@ class FilesStock(Stock, google_stock.GoogleStock):
         else: 
             coord_y = coord_y + 20
         if not self.__slideout.slideout_from(coord_x, coord_y):
-            self.__slideout.destroy()
-            self.__slideout = None
-            self.__slideout_target = None
+            self.__close_slideout()
             return
 
     def __on_documents_load(self, document_entries, gobj):
         self.__remove_files_for_key(gobj) 
         for document_entry in document_entries:
-            google_file = GoogleFile(gobj, gobj.get_account().get_username_as_google_email(),
+            google_file = GoogleFile(gobj, gobj.get_account().GetUsername(),
                                      document_entry)
             # google_file.connect('activated', self.on_file_activated)
             self.__files.append(google_file)
